import {
  APICreate,
  APIListPaginated,
  APIRemove,
  APIRetrieve,
  APIUpdate,
  createExtendableAPI,
} from '@rokoli/bnb/drf'
import { defineStore } from 'pinia'

import { createSteeringURL } from '@/api'
import { components } from '@/steering-types'
import { steeringAuthInit } from '@/stores/auth'
import { Show } from '@/types'

type KeysFrom<T, K extends keyof T> = K

type ReadonlyAttrs = KeysFrom<Show, 'id' | 'createdAt' | 'createdBy' | 'updatedAt' | 'updatedBy'>
type ShowCreateData = Omit<Show, ReadonlyAttrs>
type ShowUpdateData = ShowCreateData
type ShowPartialUpdateData = components['schemas']['PatchedShow']
export type NewShow = ShowCreateData

export function newShow(): NewShow {
  return {
    name: '',
    slug: '',
    description: '',
    shortDescription: '',
    email: '',
    internalNote: '',
    typeId: -1,
    fundingCategoryId: -1,
    isActive: true,
    isPublic: true,
    predecessorId: null,
    defaultPlaylistId: null,
    cbaSeriesId: null,
    imageId: null,
    logoId: null,
    links: [],
    topicIds: [],
    categoryIds: [],
    musicFocusIds: [],
    ownerIds: [],
    hostIds: [],
    languageIds: [],
  }
}

export const useShowStore = defineStore('shows', () => {
  const endpoint = createSteeringURL.prefix('shows')
  const { api, base } = createExtendableAPI<Show>(endpoint, steeringAuthInit)
  return {
    ...base,
    ...APIListPaginated(api),
    ...APIRetrieve(api),
    ...APICreate<Show, ShowCreateData>(api),
    ...APIUpdate<Show, ShowUpdateData, ShowPartialUpdateData>(api),
    ...APIRemove(api),
  }
})
